(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
	typeof define === 'function' && define.amd ? define(factory) :
	(global.bracketing = factory());
}(this, (function () { 'use strict';

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var bracketing_1 = createCommonjsModule(function (module) {
  'use strict';

  var bracketing = function bracketing(predicate, sequence) {
    // Keep track of the current sub array length
    var subLength = 0;
    // Array index of left value
    var leftPointer = 0;
    // Array index of right value
    var rightPointer = 1;
    // Where the current sub array starts
    var startingIndex = 0;
    // Final winning start index
    var winningStart = 0;
    // Final winning length of sub array
    var winningLength = 0;

    do {
      var leftValue = sequence[leftPointer];
      var rightValue = sequence[rightPointer];

      if (predicate(leftValue, rightValue)) {
        subLength += 1;
        leftPointer += 1;
      } else {
        if (subLength + 1 > winningLength) {
          winningStart = startingIndex;
          winningLength = startingIndex + (subLength + 1);
        }
        subLength = 0;
        leftPointer = rightPointer;
        startingIndex = leftPointer;
      }
      rightPointer += 1;
    } while (rightPointer <= sequence.length);
    return sequence.slice(winningStart, winningLength);
  };

  module.exports = bracketing;
});

return bracketing_1;

})));
